==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/it.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "The last viewed note cannot be accessed. " : "Impossibile accedere all'ultima nota visualizzata.",
    "The notes folder is not accessible: %s" : "La cartella delle note non è accessibile: %s",
    "Error" : "Errore",
    "New note" : "Nuova nota",
    "Distraction-free notes and writing" : "Note senza distrazioni e scrittura",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "L'applicazione Note è un'applicazione per prendere note senza distrazioni per [Nextcloud](https://www.nextcloud.com/). Fornisce categorie per un'organizzazione migliore e supporta la formattazione utilizzando la sintassi [Markdown](https://it.wikipedia.org/wiki/Markdown). Le note sono salvate come file nel tuo Nextcloud, in modo che tu possa visualizzarle e modificarle con ogni client Nextcloud. Inoltre, una [API REST](docs/api/README.md) separata consente un'integrazione semplice in applicazioni di terze parti (attualmente ci sono applicazioni di note per [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) e la [console](https://git.danielmoch.com/nncli/about) che consentono un accesso comodo alle note di Nextcloud). Ulteriori funzionalità includono la marcatura delle note come preferite.",
    "Settings" : "Impostazioni",
    "Deleted {title}" : "Eliminato {title}",
    "Deleted {number} notes" : "Eliminate {number} note",
    "Undo Delete" : "Annulla eliminazione",
    "Please chose a valid path in {label} (bottom left corner)." : "Scegli un percorso valido in {label} (bottom left corner).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ci sono note non salvate. Uscita. Se lasci la pagina perderai tutte le modifiche!",
    "Folder to store your notes" : "Cartella in cui memorizzare le tue note",
    "path to notes" : "percorso delle note",
    "File extension for new notes" : "Estensione dei file per le nuove note",
    "All notes" : "Tutte le note",
    "Categories" : "Categorie",
    "No search result for “{search}” in {category}" : "Nessun risultato di ricerca per \"{search}\" in {category}",
    "No search result for “{search}”" : "Nessun risultato di ricerca per \"{search}\"",
    "Loading …" : "Caricamento...",
    "Search result for “{search}” in {category}" : "Risultato di ricerca per \"{search}\" in {category}",
    "Search result for “{search}”" : "Risultato di ricerca per \"{search}\"",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "This week" : "Questa settimana",
    "Last week" : "Settimana scorsa",
    "This month" : "Questo mese",
    "Last month" : "Mese scorso",
    "Rename" : "Rinomina",
    "Note's title" : "Titolo della nota",
    "Delete note" : "Elimina nota",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Error during preparing note for deletion." : "Errore durante l'eliminazione della nota.",
    "Empty note" : "Nota vuota",
    "Write …" : "Scrivi...",
    "Details" : "Dettagli",
    "Preview" : "Anteprima",
    "Edit" : "Modifica",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Save failed. Click to retry." : "Salvataggio non riuscito. Fai clic per riprovare.",
    "Set category" : "Imposta categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Senza categoria",
    "Click here to save manually" : "Fai clic qui per salvare manualmente",
    "Saving failed!" : "Salvataggio non riuscito!",
    "Last modified: {date}" : "Ultima modifica: {date}",
    "Note has unsaved changes" : "La nota ha modifiche non salvate",
    "Subcategory" : "Sottocategoria",
    "_%n word_::_%n words_" : ["%n parola","%n parole"],
    "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
    "Organize your notes in categories." : "Organizza le tue note in categorie.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa l'applicazione per il tuo cellulare per accedere alle tue note da ovunque.",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Puoi creare sottocategorie utilizzando \"/\" come delimitatore tra la categoria superiore e la sottocategoria, ad. es \"{parent}/{sub}\".",
    "See JavaScript console and server log for details." : "Vedi la console JavaScript e i log del server per i dettagli.",
    "Saving the note has failed due to insufficient storage." : "Il salvataggio della nota non è riuscito a causa di spazio di archiviazione insufficiente.",
    "Updating settings has failed." : "Aggiornamento delle impostazioni non riuscito.",
    "Fetching notes has failed." : "Recupero delle note non riuscito.",
    "Fetching note {id} has failed." : "Recupero della nota {id} non riuscito.",
    "Renaming note {id} has failed." : "La rinomina della nota {id} non è riuscita.",
    "Creating new note has failed." : "Creazione nuova nota non riuscita.",
    "Updating note {id} has failed." : "Aggiornamento della nota {id} non riuscito.",
    "Undo delete has failed for note {title}." : "Annullamento eliminazione non riuscito per la nota {title}.",
    "Deleting note {id} has failed." : "Eliminazione della nota {id} non riuscita.",
    "Toggling favorite for note {id} has failed." : "L'attivazione come preferito della nota {id} non è riuscita",
    "Updating the note's category has failed. Is the target directory writable?" : "L'aggiornamento della categoria delle note non è riuscito. La cartella di destinazione è scrivibile?",
    "Updating the category for note {id} has failed." : "Aggiornamento della categoria per la nota {id} non riuscito.",
    "Development Mode" : "Modalità di sviluppo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembra che l'applicazione delle note sia stata installata da una sorgente di sviluppo. Installala invece dal <a href=\"%1$s\">Negozio delle applicazioni di Nextcloud</a> ufficiale. Se desideri compilare l'applicazione Note in autonomia, segui le <a href=\"%2$s\">istruzioni per sviluppatori</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/it.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "La lettura delle note dal filesystem non è riuscita.",
    "Error" : "Errore",
    "New note" : "Nuova nota",
    "Notes" : "Note",
    "Distraction-free notes and writing" : "Note senza distrazioni e scrittura",
    "Please see Nextcloud server log for details." : "Vedi i log del server Nextcloud per i dettagli.",
    "Deleted {title}" : "Eliminato {title}",
    "Deleted {number} notes" : "Eliminate {number} note",
    "Undo Delete" : "Annulla eliminazione",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ci sono note non salvate. Uscita. Se lasci la pagina perderai tutte le modifiche!",
    "Settings" : "Impostazioni",
    "Folder to store your notes" : "Cartella in cui memorizzare le tue note",
    "path to notes" : "percorso delle note",
    "File extension for new notes" : "Estensione dei file per le nuove note",
    "All notes" : "Tutte le note",
    "Categories" : "Categorie",
    "No search result for “{search}” in {category}" : "Nessun risultato di ricerca per \"{search}\" in {category}",
    "No search result for “{search}”" : "Nessun risultato di ricerca per \"{search}\"",
    "Loading …" : "Caricamento...",
    "Search result for “{search}” in {category}" : "Risultato di ricerca per \"{search}\" in {category}",
    "Search result for “{search}”" : "Risultato di ricerca per \"{search}\"",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "This week" : "Questa settimana",
    "Last week" : "Settimana scorsa",
    "This month" : "Questo mese",
    "Last month" : "Mese scorso",
    "Rename" : "Rinomina",
    "Note's title" : "Titolo della nota",
    "Delete note" : "Elimina nota",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Error during preparing note for deletion." : "Errore durante l'eliminazione della nota.",
    "Empty note" : "Nota vuota",
    "Write …" : "Scrivi...",
    "Details" : "Dettagli",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modifica",
    "Preview" : "Anteprima",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Save failed. Click to retry." : "Salvataggio non riuscito. Fai clic per riprovare.",
    "Set category" : "Imposta categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Senza categoria",
    "Click here to save manually" : "Fai clic qui per salvare manualmente",
    "Saving failed!" : "Salvataggio non riuscito!",
    "Last modified: {date}" : "Ultima modifica: {date}",
    "Note has unsaved changes" : "La nota ha modifiche non salvate",
    "Subcategory" : "Sottocategoria",
    "_%n word_::_%n words_" : ["%n parola","%n parole"],
    "_%n character_::_%n characters_" : ["%n carattere","%n caratteri"],
    "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
    "Organize your notes in categories." : "Organizza le tue note in categorie.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa l'applicazione per il tuo cellulare per accedere alle tue note da ovunque.",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Puoi creare sottocategorie utilizzando \"/\" come delimitatore tra la categoria superiore e la sottocategoria, ad. es \"{parent}/{sub}\".",
    "Note not found." : "Nota non trovata.",
    "Note is locked." : "La nota è bloccata.",
    "Insufficient storage." : "Spazio di archiviazione insufficiente.",
    "See JavaScript console and server log for details." : "Vedi la console JavaScript e i log del server per i dettagli.",
    "Updating settings has failed." : "Aggiornamento delle impostazioni non riuscito.",
    "Error from Nextcloud server: {msg}" : "Errore dal server di Nextcloud: {msg}",
    "Fetching notes has failed." : "Recupero delle note non riuscito.",
    "Fetching note {id} has failed." : "Recupero della nota {id} non riuscito.",
    "Refreshing note {id} has failed." : "L'aggiornamento della nota {id} non è riuscito.",
    "Renaming note {id} has failed." : "La rinomina della nota {id} non è riuscita.",
    "Creating new note has failed." : "Creazione nuova nota non riuscita.",
    "Saving note {id} has failed." : "Il salvataggio della nota {id} non è riuscito.",
    "Updating title for note {id} has failed." : "L'aggiornamento del titolo per la nota {id} non è riuscito.",
    "Undo delete has failed for note {title}." : "Annullamento eliminazione non riuscito per la nota {title}.",
    "Deleting note {id} has failed." : "Eliminazione della nota {id} non riuscita.",
    "Toggling favorite for note {id} has failed." : "L'attivazione come preferito della nota {id} non è riuscita",
    "Updating the note's category has failed. Is the target directory writable?" : "L'aggiornamento della categoria delle note non è riuscito. La cartella di destinazione è scrivibile?",
    "Updating the category for note {id} has failed." : "Aggiornamento della categoria per la nota {id} non riuscito.",
    "Development Mode" : "Modalità di sviluppo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembra che l'applicazione delle note sia stata installata da una sorgente di sviluppo. Installala invece dal <a href=\"%1$s\">Negozio delle applicazioni di Nextcloud</a> ufficiale. Se desideri compilare l'applicazione Note in autonomia, segui le <a href=\"%2$s\">istruzioni per sviluppatori</a>"
},
"nplurals=2; plural=(n != 1);");
